import type { Jws, JwsGeneralFormat, JwsProtectedHeaderOptions } from './JwsTypes';
import type { Key } from './Key';
import type { AgentContext } from '../agent';
import type { Buffer } from '../utils';
export declare class JwsService {
    private createJwsBase;
    createJws(agentContext: AgentContext, { payload, key, header, protectedHeaderOptions }: CreateJwsOptions): Promise<JwsGeneralFormat>;
    /**
     *  @see {@link https://www.rfc-editor.org/rfc/rfc7515#section-3.1}
     * */
    createJwsCompact(agentContext: AgentContext, { payload, key, protectedHeaderOptions }: CreateCompactJwsOptions): Promise<string>;
    /**
     * Verify a JWS
     */
    verifyJws(agentContext: AgentContext, { jws, payload }: VerifyJwsOptions): Promise<VerifyJwsResult>;
    private buildProtected;
    private jwkFromProtectedHeader;
}
export interface CreateJwsOptions {
    key: Key;
    payload: Buffer;
    header: Record<string, unknown>;
    protectedHeaderOptions: JwsProtectedHeaderOptions;
}
type CreateCompactJwsOptions = Omit<CreateJwsOptions, 'header'>;
export interface VerifyJwsOptions {
    jws: Jws;
    payload: Buffer;
}
export interface VerifyJwsResult {
    isValid: boolean;
    signerKeys: Key[];
}
export {};
